Serializer

Struct Serializer 

pub struct Serializer { /* private fields */ }
Serializes values into property lists.

A property list holds a single value.

use deser_plist::Serializer;

let mut serializer = Serializer::new();
serializer.serialize(&true).unwrap();
assert!(serializer.output().ends_with(b"<plist version=\"1.0\">\n<true/>\n</plist>\n"));

The serializer is also the stream serializer of property lists (see StreamSerializer). XML and OpenStep property lists can be written in parts, binary property lists are written once the value is complete as the object table needs all objects. To write to a Write use SerializerConfig::writer.

Implementations

Source

impl Serializer

pub fn new() -> Serializer

Creates a serializer.

pub fn with_config(config: SerializerConfig) -> Serializer

Creates a serializer with the given configuration.

pub fn config(&self) -> &SerializerConfig

Returns the configuration.

pub fn written(&self) -> bool

Returns true once the value was written.

pub fn serialize<T: Serialize + ?Sized>( &mut self, value: &T, ) -> Result<(), Error>

Serializes a value.

A property list holds a single value, serializing a second value fails.

pub fn serialize_with<F, T: Serialize + ?Sized>( &mut self, value: &T, setup: F, ) -> Result<(), Error>
where F: FnOnce(&mut SerializeDriver<'_>),

Serializes a value with a configured driver.

The callback is invoked with the driver before the value is serialized, for instance to add Layers.

pub fn output(&self) -> &[u8] ⓘ

Returns the output written so far (that was not cleared).

pub fn finish(self) -> Vec<u8> ⓘ

Returns the output.