SerializerConfig

Struct SerializerConfig 

pub struct SerializerConfig { /* private fields */ }
Configures how values are serialized to property lists.

The set_format selects the encoding, by default XML is written.

use deser_plist::{Format, SerializerConfig};

const BINARY: SerializerConfig = SerializerConfig::builder().format(Format::Binary).build();
let bytes = BINARY.to_vec(&vec![1, 2, 3]).unwrap();
assert!(bytes.starts_with(b"bplist00"));

const ASCII: SerializerConfig = SerializerConfig::builder().format(Format::Ascii).build();
assert_eq!(ASCII.to_string(&vec![1, 2, 3]).unwrap(), "(\n\t1,\n\t2,\n\t3,\n)\n");

Implementations

Source

impl SerializerConfig

pub const fn new() -> SerializerConfig

Creates the default configuration.

pub const fn builder() -> SerializerConfigBuilder

Returns a builder for the configuration (see SerializerConfigBuilder).

pub const fn into_builder(self) -> SerializerConfigBuilder

Returns a builder that starts with this configuration.

pub fn set_context(&mut self, context: Context)

Sets the context the values are serialized in.

The values of the context are the defaults of the extension values of the state (see Context), for instance the BytesFormat. The serializers and writers created with the configuration use this context. A context set on the driver takes precedence.

pub fn context(&self) -> &Context

Returns the context the values are serialized in.

pub const fn set_format(&mut self, format: Format)

Sets the format to write.

pub fn to_vec<T: Serialize + ?Sized>(&self, value: &T) -> Result<Vec<u8>, Error>

Serializes the given value.

pub fn to_vec_with<F, T: Serialize + ?Sized>( &self, value: &T, setup: F, ) -> Result<Vec<u8>, Error>
where F: FnOnce(&mut SerializeDriver<'_>),

Serializes the given value with a configured driver.

The callback is invoked with the driver before the serialization starts, for instance to add Layers.

pub fn to_string<T: Serialize + ?Sized>( &self, value: &T, ) -> Result<String, Error>

Serializes the given value into a string.

This fails for the binary format.

Source

impl SerializerConfig

pub fn writer<W: Write>(&self, writer: W) -> Writer<W, Serializer>

Creates a writer of a property list (see deser::io::Writer).

A stream holds a single property list, writing a second value fails. XML and OpenStep property lists are written in parts while the value is serialized. Binary property lists are written once the value is complete as the object table needs all objects.

pub fn to_writer<W: Write, T: Serialize + ?Sized>( &self, writer: W, value: &T, ) -> Result<(), Error>

Serializes a value to a writer.

See to_writer.