pub struct Serializer { /* private fields */ }Expand description
Serializes values into property lists.
A property list holds a single value.
use deser_plist::Serializer;
let mut serializer = Serializer::new();
serializer.serialize(&true).unwrap();
assert!(serializer.output().ends_with(b"<plist version=\"1.0\">\n<true/>\n</plist>\n"));The serializer is also the stream serializer of property lists (see
StreamSerializer). XML and OpenStep
property lists can be written in parts, binary property lists are
written once the value is complete as the object table needs all
objects. To write to a Write use
SerializerConfig::writer.
Implementations
Sourceimpl Serializer
impl Serializer
Sourcepub fn new() -> Serializer
pub fn new() -> Serializer
Creates a serializer.
Sourcepub fn with_config(config: SerializerConfig) -> Serializer
pub fn with_config(config: SerializerConfig) -> Serializer
Creates a serializer with the given configuration.
Sourcepub fn config(&self) -> &SerializerConfig
pub fn config(&self) -> &SerializerConfig
Returns the configuration.
Sourcepub fn serialize<T: Serialize + ?Sized>(
&mut self,
value: &T,
) -> Result<(), Error>
pub fn serialize<T: Serialize + ?Sized>( &mut self, value: &T, ) -> Result<(), Error>
Serializes a value.
A property list holds a single value, serializing a second value fails.